# heathotspotsgee


[![image](https://img.shields.io/pypi/v/heathotspotsgee.svg)](https://pypi.python.org/pypi/heathotspotsgee)
[![image](https://img.shields.io/conda/vn/conda-forge/heathotspotsgee.svg)](https://anaconda.org/conda-forge/heathotspotsgee)


**Heat Hotspots using GEE**


-   Free software: MIT license
-   Documentation: https://Sub-esh.github.io/heathotspotsgee
    

## Features

-   TODO
